#!/bin/bash -

PROJECT=febootstrap
MAILTO=libguestfs@redhat.com
HOSTNAME="$(hostname -s)"

#----------------------------------------------------------------------
# Helper functions.

failed ()
{
    mail -s "$HOSTNAME $PROJECT FAILED $1 $gitsha" $MAILTO < local-log
}

ok ()
{
    mail -s "$HOSTNAME $PROJECT success $gitsha" $MAILTO < local-log
}

#----------------------------------------------------------------------

set -e
set -x

rm -f local-log
cat > local-log <<EOF

This is an automatic message generated by the builder on
$HOSTNAME for $PROJECT.  Log files from the build
follow below.

$(uname -a)
$(date)

-----

EOF
exec >> local-log 2>&1

# Pull from the public repo so that we don't need ssh-agent.
git pull --rebase git://git.annexia.org/git/febootstrap.git master
git clean -d -f

# The git version we are building.
gitsha=$(git log|head -1|awk '{print $2}')

# Do the configure step.
./autogen.sh || {
    failed "configure step"
    exit 1
}

# Do the build step.
make || {
    failed "build step"
    exit 1
}

# Run the tests.
make check || {
    failed "tests"
    exit 1
}

ok
